==> haskell-hspec-wai-0.9.0-55-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-HTXvzWt47O9C1HzBEQxrea
key: hspec-wai-0.9.0-HTXvzWt47O9C1HzBEQxrea
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
abi: 77db1101ad0e9246156c0d30152b1b90
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-HTXvzWt47O9C1HzBEQxrea
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    hspec-core-2.5.0-CLMnjmO5MHF2WxbBBpxrXt
    hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d
    wai-extra-3.0.22.0-AwWKtaHEdM31GuajH3rGSJ
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             hspec-core-2.5.0-CLMnjmO5MHF2WxbBBpxrXt=bf454e4174d7b053ff3417c8172583a6
             hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah=8091a35c554a78c5c9d9fd128126d629
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d=96f45cdb47a7c3edf990f6259e0df5e1
             wai-extra-3.0.22.0-AwWKtaHEdM31GuajH3rGSJ=002940cb889d49e5ab335631c7d354ca
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.9.0-57-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-4uLUS9ERakHIYPJIyUborm
key: hspec-wai-0.9.0-4uLUS9ERakHIYPJIyUborm
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
abi: c36aeb0013a1fcaa9a9994700ccd8332
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-4uLUS9ERakHIYPJIyUborm
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    hspec-core-2.5.0-CLMnjmO5MHF2WxbBBpxrXt
    hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d
    wai-extra-3.0.22.0-26hsFVGp9m0FgTmdmGXnfa
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             hspec-core-2.5.0-CLMnjmO5MHF2WxbBBpxrXt=bf454e4174d7b053ff3417c8172583a6
             hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah=8091a35c554a78c5c9d9fd128126d629
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d=96f45cdb47a7c3edf990f6259e0df5e1
             wai-extra-3.0.22.0-26hsFVGp9m0FgTmdmGXnfa=5c56aa42ad06a5871792596d2a8416b4
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
